Title: [110795] trunk/Tools
Revision
110795
Author
timothy_hor...@apple.com
Date
2012-03-14 17:10:02 -0700 (Wed, 14 Mar 2012)

Log Message

NRWT should respect --additional-platform-directory's Skipped list
https://bugs.webkit.org/show_bug.cgi?id=81172

Reviewed by Timothy Hatcher.

Respect the Skipped file inside all paths included via the --additional-platform-directory option. Test results
from said path are already used, but the Skipped file is ignored.

* Scripts/webkitpy/layout_tests/port/webkit.py:
(WebKitPort._skipped_file_search_paths):
* Scripts/webkitpy/layout_tests/port/webkit_unittest.py:
(test_skipped_file_search_paths):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (110794 => 110795)


--- trunk/Tools/ChangeLog	2012-03-15 00:08:34 UTC (rev 110794)
+++ trunk/Tools/ChangeLog	2012-03-15 00:10:02 UTC (rev 110795)
@@ -1,3 +1,18 @@
+2012-03-14  Tim Horton  <timothy_hor...@apple.com>
+
+        NRWT should respect --additional-platform-directory's Skipped list
+        https://bugs.webkit.org/show_bug.cgi?id=81172
+
+        Reviewed by Timothy Hatcher.
+
+        Respect the Skipped file inside all paths included via the --additional-platform-directory option. Test results
+        from said path are already used, but the Skipped file is ignored.
+
+        * Scripts/webkitpy/layout_tests/port/webkit.py:
+        (WebKitPort._skipped_file_search_paths):
+        * Scripts/webkitpy/layout_tests/port/webkit_unittest.py:
+        (test_skipped_file_search_paths):
+
 2012-03-14  Ojan Vafai  <o...@chromium.org>
 
         Unreviewed, rolling out r110783.

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit.py (110794 => 110795)


--- trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit_unittest.py	2012-03-15 00:08:34 UTC (rev 110794)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit_unittest.py	2012-03-15 00:10:02 UTC (rev 110795)
@@ -151,6 +151,8 @@
         self.assertEqual(port._skipped_file_search_paths(), set(['testwebkitport', 'testwebkitport-version']))
         port._options = MockOptions(webkit_test_runner=True)
         self.assertEqual(port._skipped_file_search_paths(), set(['testwebkitport', 'testwebkitport-version', 'testwebkitport-wk2', 'wk2']))
+        port._options = MockOptions(additional_platform_directory=["internal-testwebkitport"])
+        self.assertEqual(port._skipped_file_search_paths(), set(['testwebkitport', 'testwebkitport-version', 'internal-testwebkitport']))
 
     def test_root_option(self):
         port = TestWebKitPort()
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to
--- trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit.py	2012-03-15 00:08:34 UTC (rev 110794)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit.py	2012-03-15 00:10:02 UTC (rev 110795)
@@ -333,7 +333,8 @@
         return "%s-wk2" % self.port_name
 
     def _skipped_file_search_paths(self):
         # Unlike baseline_search_path, we only want to search [WK2-PORT, PORT-VERSION, PORT] not the full casade.
         # Note order doesn't matter since the Skipped file contents are all combined.
         search_paths = set([self.port_name])
         if 'future' not in self.name():
@@ -342,6 +343,8 @@
             # Because nearly all of the skipped tests for WebKit 2 are due to cross-platform
             # issues, all wk2 ports share a skipped list under platform/wk2.
             search_paths.update([self._wk2_port_name(), "wk2"])
+        search_paths.update(self.get_option("additional_platform_directory", []))
+
         return search_paths
 
     def test_expectations(self):
@@ -333,7 +333,8 @@
 
     def _skipped_file_search_paths(self):
-        # Unlike baseline_search_path, we only want to search [WK2-PORT, PORT-VERSION, PORT] not the full casade.
+        # Unlike baseline_search_path, we only want to search [WK2-PORT, PORT-VERSION, PORT] and any directories
+        # included via --additional-platform-directory, not the full casade.
         # Note order doesn't matter since the Skipped file contents are all combined.
         search_paths = set([self.port_name])

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/port/webkit_unittest.py (110794 => 110795)

